@@ -1,10 +1,10 @@
 '''
 urledit
-======
-URL parsing and editing in the object or functional style.
+=======
+Url parsing and editing as an object or in a functional style.
 
     >>> from urledit import urledit
-    >>> url = 'forum/showthread.php?s=9b5d99fc6a61a17cc07326714500b3ab&p=728386#post728386'
+    >>> url = 'forum/showthread.php?s=12345&p=728386#post728386'
 
 Functional style
 ----------------
@@ -22,16 +22,16 @@ Object style
 ------------
     >>> u = urledit(url)
     >>> u.scheme, u.netloc, u.path, u.qs, u.fragment
-    ('', '', 'forum/showthread.php', 's=9b5d99fc6a61a17cc07326714500b3ab&p=728386', 'post728386')
+    ('', '', 'forum/showthread.php', 's=12345&p=728386', 'post728386')
 
     >>> u.scheme, u.netloc, u.fragment = 'http', 'host.com', ''
     >>> u.join()
-    'http://host.com/forum/showthread.php?s=9b5d99fc6a61a17cc07326714500b3ab&p=728386'
+    'http://host.com/forum/showthread.php?s=12345&p=728386'
 
 Working with query string:
 
     >>> u.query
-    {'p': '728386', 's': '9b5d99fc6a61a17cc07326714500b3ab'}
+    {'p': '728386', 's': '12345'}
 
     >>> del u.query['s']
     >>> u.join()
@@ -45,7 +45,7 @@ Working with query string:
 import urllib
 import urlparse
 
-__version__ = '1.0'
+__version__ = '1.0.1'
 
 
 class urledit(object):
@@ -62,7 +62,7 @@ class urledit(object):
     @property
     def query(self):
         self._qs_changed = True
-        if not self._query:
+        if self._query is None:
             self._query = QS(self._qs)
         return self._query
 
@@ -121,8 +121,9 @@ class QS(dict):
                 vs = [vs]
             for v in vs:
                 pairs.append((k, v))
-        pairs.sort(key=lambda x: self.order.index(x[0])
-                if x[0] in self.order else len(self.order))
+        pairs.sort(
+            key=lambda x: self.order.index(x[0])
+            if x[0] in self.order else len(self.order))
         return urllib.urlencode(pairs)
 
 
